package frc.robot.subsystems;

import com.revrobotics.CANSparkBase.IdleMode;
import com.revrobotics.CANSparkLowLevel.MotorType;
import com.revrobotics.CANSparkMax;
import com.revrobotics.RelativeEncoder;

import edu.wpi.first.math.controller.ArmFeedforward;
import edu.wpi.first.math.controller.PIDController;
import edu.wpi.first.math.util.Units;
import edu.wpi.first.wpilibj2.command.SubsystemBase;
import frc.robot.constants.IntakeRollerConstants;
import frc.robot.constants.IntakePivotConstants;

public class IntakePivot extends SubsystemBase {
    private CANSparkMax intakePivot;

    private RelativeEncoder intakeEncoder;

    private PIDController intakeAnglePID;

    private ArmFeedforward intakeFeedForward;

    private double armOffset;

    public IntakePivot() {
        intakePivot = new CANSparkMax(IntakePivotConstants.kIntakePivotID, MotorType.kBrushless);

        intakePivot.setIdleMode(IdleMode.kBrake);
        intakePivot.setSmartCurrentLimit(IntakePivotConstants.kPivotCurrentLimit);
        intakePivot.setInverted(true);
        intakePivot.burnFlash();

        intakeEncoder = intakePivot.getEncoder();
        intakeEncoder.setPosition(Units.radiansToRotations(IntakePivotConstants.kStartingAngle));

        intakeAnglePID = new PIDController(
            IntakePivotConstants.kP
        );

        intakeFeedForward = new ArmFeedforward(
            IntakeRollerConstants.kSFeedForward, 
            IntakeRollerConstants.kGFeedForward, 
            IntakeRollerConstants.kVFeedForward
        );

    }
}
